Index: build/mac/change_mach_o_flags_from_xcode.sh |
=================================================================== |
--- build/mac/change_mach_o_flags_from_xcode.sh (revision 97870) |
+++ build/mac/change_mach_o_flags_from_xcode.sh (working copy) |
@@ -4,12 +4,11 @@ |
# Use of this source code is governed by a BSD-style license that can be |
# found in the LICENSE file. |
# This is a small wrapper script around make_heap_non_executable.py allowing |
# it to be invoked easily from Xcode. make_heap_non_executable.py expects its |
# argument on the command line, and Xcode puts all of its parameters in the |
# environment. |
set -e |
-exec "$(dirname "${0}")/make_heap_non_executable.py" \ |
+exec "$(dirname "${0}")/change_mach_o_flags.py" \ |
"${BUILT_PRODUCTS_DIR}/${EXECUTABLE_PATH}" |
@@ -4,12 +4,11 @@ |
# Use of this source code is governed by a BSD-style license that can be |
# found in the LICENSE file. |
-# This is a small wrapper script around make_heap_non_executable.py allowing |
-# it to be invoked easily from Xcode. make_heap_non_executable.py expects its |
-# argument on the command line, and Xcode puts all of its parameters in the |
-# environment. |
+# This is a small wrapper script around change_mach_o_flags.py allowing it to |
+# be invoked easily from Xcode. change_mach_o_flags.py expects its arguments |
+# on the command line, but Xcode puts its parameters in the environment. |
set -e |